/*----[ table based form tags ]----------------------------------------------*/

form.edit-form {
    margin: 0px;
    padding: 0px;
}

form.edit-form td {
    vertical-align: top;
    padding-bottom: 10px;
}

form.edit-form td.label {
    margin: 0px;
    padding-top: 5px;
}

div.viewspace {
    margin: 0px;
    padding: 0px;
}

div.status {
    padding-bottom: 10px;
}

div.summary {
    margin: 0px;
    padding: 0px;
}

ul.errors {
    padding: 0px;
    color: red;
    margin-left: 20px;
}

div.error {
    margin: 0px;
    padding: 0px;
}

div.required-info span.required, td.label span.required {
    color: red;
}

div.widget {
    margin: 0px;
    padding: 0px;
}

input, textarea, select {
    margin: 0px;
    padding: 0px;
    border: 1px solid gray;
}

input.file-widget {
    width: 300px;
}

input.checkbox-widget {
    border: none;
}

input.password-widget {
    width: 300px;
}

input.radio-widget {
    border: none;
}

select.select-widget {
    width: 300px;
    border: 1px solid gray;
}

input.text-widget {
    width: 300px;
}

textarea.textarea-widget {
    width: 300px;
    height: 100px;
}

div.buttons {
    padding: 10px 0px 10px 0px;
}


/*---[ multi widget ]--------------------------------------------------------*/

div.multi-widget div.multi-widget-checkbox {
    float: left
}

div.multi-widget div.label {
    margin: 0px;
    padding: 0px;
    padding: 0px 0px 00px 20px;
}

div.multi-widget input.password-widget {
    width: 280px;
}

div.multi-widget input.text-widget {
    width: 280px;
}

div.multi-widget textarea.textarea-widget {
    width: 280px;
    height: 100px;
}

div.multi-widget div.buttons {
    padding: 0px 0px 10px 20px;
}
